pub struct JWT {
inner: String,
}Expand description
Fields
inner: StringImplementations
Sourceimpl JWT
impl JWT
Sourcepub fn create<C: Serialize, SK: SigningKey>(
claims: &C,
key: &SK,
) -> Result<JWT, Error>
pub fn create<C: Serialize, SK: SigningKey>( claims: &C, key: &SK, ) -> Result<JWT, Error>
Creates JWT from claims and SigningKey key.
You can also use Claims::sign
Sourcepub fn open<VK: VerifyingKey>(&self, key: &VK) -> Result<Claims, Error>
pub fn open<VK: VerifyingKey>(&self, key: &VK) -> Result<Claims, Error>
Checks the validity of this jwt against the given VerifyingKey key, and the JSON syntax
of the claims. Does not check the validity of the claims itself.
If only the signature is invalid, the claims can be extracted from
Error::InvalidSignature::claims.
pub fn as_str(&self) -> &str
pub fn sha256(&self) -> Sha256
pub fn id(&self) -> Id