pub struct NumericDate {
timestamp: u64,
}Expand description
Represents the value of the iat, exp, nbf claims.
According to RFC7519, it should be:
“A JSON numeric value representing the number of seconds from 1970-01-01T00:00:00Z UTC until the specified UTC date/time, ignoring leap seconds. This is equivalent to the IEEE Std 1003.1, 2013 Edition [POSIX.1] definition “Seconds Since the Epoch”, in which each day is accounted for by exactly 86400 seconds, other than that non-integer values can be represented.“
But contrary to this, we will reject negative timestamps with an error, and silently round down non-negative decimals to the nearest u64.
Fields
timestamp: u64Implementations